@@ -308,11 +308,14 @@ class UnbabelApi(object):
 
 
 
-    def get_translations(self):
+    def get_translations(self,status=None):
         '''
             Returns the translations requested by the user
         '''
-        result = self.api_call('translation/')
+        if status is not None:
+            result = self.api_call('translation/?status=%s'%status)
+        else:
+            result = self.api_call('translation/')
         if result.status_code == 200:
             translations_json = json.loads(result.content)["objects"]
             translations = [Translation(**tj) for tj in translations_json]
@@ -390,104 +393,6 @@ class UnbabelApi(object):
         account = Account(**account_data)
         return account
 
-    def post_order(self,
-                   callback_url = None,
-                   origin = None):
-        data = {}
-        if callback_url is not None:
-            data["callback_url"] = callback_url
-        if origin is not None:
-            data["origin"] = origin
-
-        result = self.api_call('order/', data)
-        if result.status_code == 201:
-            json_object = json.loads(result.content)
-            id = json_object.get('id')
-            status = json_object.get('status')
-            price = json_object.get('price')
-            order = Order(id, status, price)
-            return order
-        elif result.status_code == 401:
-            raise UnauthorizedException(result.content)
-        elif result.status_code == 400:
-            raise BadRequestException(result.content)
-        else:
-            log.debug(result)
-            raise Exception("Unknown Error")
-
-    def post_job(self,
-                 order_id,
-                 text,
-                 source_language,
-                 target_language,
-                 target_text='',
-                 text_format="text",
-                 uid=None,
-                 tone=None,
-                 topic=[],
-                 visibility=None,
-                 instructions='',
-                 public_url=None,
-                 callback_url=None,
-                 job_type='paid'):
-
-        data = {
-            'order_id': order_id,
-            'text': text,
-            'target_text': target_text,
-            'text_format': text_format,
-            'source_language': source_language,
-            'target_language': target_language,
-            'uid': uid,
-            'tone': tone,
-            'topic': topic,
-            'visibility': visibility,
-            'instructions': instructions,
-            'public_url': public_url,
-            'callback_url': callback_url,
-            'type': job_type,
-        }
-
-        result = self.api_call('job/', data)
-
-        if result.status_code == 201:
-            json_object = json.loads(result.content)
-            #log.debug(json_object)
-            job = Job(
-                id=json_object['id'],
-                uid=json_object['uid'],
-                order_id = json_object['order']['id'],
-                price=json_object['price'],
-                source_language=json_object['source_language'],
-                target_language=json_object['target_language'],
-                tone=json_object['tone'],
-                text = json_object['text'],
-                status = json_object['status'],
-                text_format=json_object['text_format']
-            )
-            return job
-        elif result.status_code == 401:
-            raise UnauthorizedException(result.content)
-        elif result.status_code == 400:
-            raise BadRequestException(result.content)
-        else:
-            log.debug('Got a HTTP Error [{}] [{}]'.format(result.status_code,result.content))
-            #log.debug(result.content)
-            raise Exception("Unknown Error")
-
-    def pay_order(self, order_id):
-        data = { 'order_id': order_id }
-        result = self.api_call('pay/', data)
-
-        if result.status_code == 201:
-            return True
-        elif result.status_code == 401:
-            raise UnauthorizedException(result.content)
-        elif result.status_code == 400:
-            raise BadRequestException(result.content)
-        else:
-            logger.debug(result)
-            raise Exception("Unknown Error")
 
     def get_word_count(self, text):
         result = self.api_call('wordcount/', {"text": text})
